![DiracX tests](https://github.com/DIRACGrid/diracx/actions/workflows/main.yml/badge.svg?branch=main)
![Legacy tests](https://github.com/DIRACGrid/diracx/actions/workflows/integration.yml/badge.svg?branch=main)
![DiracX deployment](https://github.com/DIRACGrid/diracx/actions/workflows/deployment.yml/badge.svg?branch=main)

# DiracX

This repository contains the code for DiracX.
It is still incomplete. Check the current progress on our [status board](https://github.com/orgs/DIRACGrid/projects/2/views/2).

Feel free to look around however try not to draw any conclusions as the code is still rapidly evolving.

## Getting started

Follow the instructions in the [diracx-charts README](https://github.com/DIRACGrid/diracx-charts?tab=readme-ov-file#running-the-demo-locally) to try it out.

## Documentation

The documentation is scattered around [various files](./docs/).

## Publications and presentations

- [The NeXt Dirac Incarnation - CHEP 24](https://indico.cern.ch/event/1338689/contributions/6010971/)
- [Eventually coming with some Documentation - Dirac User Workshop 24](https://indico.cern.ch/event/1341205/contributions/5972930/)
- [Demo and Technical details - Dirac & Rucio Workshop 23](https://indico.cern.ch/event/1252369/contributions/5515392/)
- [Dirac: future Part1](https://indico.cern.ch/event/1292287/) and [Part2 - Bild-Dev meeting June 23](https://indico.cern.ch/event/1297397/)
